@@ -1,5 +1,5 @@
 library(roxygen2)
-dir='~/Dropbox/bfa/pkg'
+dir='~/Dropbox/R_packages/bfa'
 setwd(dir)
 
 #f = paste('~/Documents/svn/bfa/pkg/man/',list.files('~/Documents/svn/bfa/pkg/man/'), sep='')
